import React, { useEffect, useRef, useLayoutEffect, useState } from "react";
import { gsap } from "gsap";
import Globe from "./globe";
import { motion, useScroll, useTransform } from "framer-motion";
import { ScrollTrigger } from "gsap/dist/ScrollTrigger";
import {
  AlertTriangleIcon,
  LucideArrowRight,
  LucideArrowRightFromLine,
  MousePointerClick,
} from "lucide-react";
import Footer from "./footer";
import { Alert, AlertDescription, AlertTitle } from "@/components/ui/alert";

gsap.registerPlugin(ScrollTrigger);

function HomePage() {
  const ref = useRef<HTMLDivElement>(null);
  const [year, setYear] = useState(2020);

  useEffect(() => {
    const element = ref.current;

    if (!element) return;

    const updateScrollValue = (progress: number) => {
      console.log("update year", progress * 30 + 2020);
      setYear(progress * 30 + 2020); // `self.progress()` returns a value between 0 and 1
    };

    // Use gsap.context for scoping
    let ctx = gsap.context(() => {
      // Create a GSAP timeline with ScrollTrigger

      //problemnumbers
      // Animate the text elements
      gsap.to(element.querySelector(".problemnumbers"), {
        scrollTrigger: {
          start: "center center",
          end: "+=600px",
          trigger: element.querySelector(".problemnumbers"),
          scrub: true,
          pin: true,
        },
      });

      gsap.to(element.querySelector(".globe"), {
        scrollTrigger: {
          start: "center center",
          end: "+=1000px",
          trigger: element.querySelector(".globe"),
          scrub: true,
          pin: true,
          onUpdate: (self) => {
            updateScrollValue(self.progress);
          },
        },
      });

      // gsap.to(element.querySelector(".parentsection"), {
      //   scrollTrigger: {
      //     start: "center center",
      //     end: "+=2200px",
      //     trigger: element.querySelector(".parentsection"),
      //     scrub: true,
      //     pin: true,
      //   },
      // })

      gsap
        .timeline({
          scrollTrigger: {
            start: "center center",
            end: "+1000px",
            trigger: element.querySelector(".parentsection"),
            scrub: true,
            pin: true,
            markers: false,
          },
        })
        .to(element.querySelector(".statusquotext"), {
          opacity: 1,
          duration: 1,
        })
        .to(element.querySelector(".statusquotext"), {
          duration: 4,
        })
        .to(element.querySelector(".statusquotext"), {
          opacity: 0,
        })
        .to(element.querySelector(".methodologytext"), {
          opacity: 1,
          duration: 1,
        })
        .to(element.querySelector(".methodologytext"), {
          duration: 4,
        })
        .to(element.querySelector(".methodologytext"), {
          opacity: 0,
        });

      gsap.to(".gifanimation", {
        scrollTrigger: {
          start: "center center",
          end: "+600px",
          trigger: element.querySelector(".gifanimation"),
          scrub: true,
          pin: true,
          markers: false,
        },
      });
      // .fromTo(
      //   element.querySelector(".ourapproachtext"),
      //   { opacity: 0 },
      //   {
      //     opacity: 1,
      //     scrollTrigger: {
      //       trigger: element.querySelector(".ourapproachtext"),
      //       start: "+=800px",
      //       end: "+=200px",
      //       scrub: true,
      //       markers: false,
      //     },
      //   }
      // )
      // .to(element.querySelector(".ourapproachtext"), {
      //   opacity: 0,
      //   scrollTrigger: {
      //     trigger: element.querySelector(".ourapproachtext"),
      //     start: "+=1500px",
      //     end: "+=200px",
      //     scrub: true,
      //     markers: false,
      //   },
      // })
      // .fromTo(
      //   element.querySelector(".methodologytext"),
      //   { opacity: 0 },
      //   {
      //     opacity: 1,
      //     scrollTrigger: {
      //       trigger: element.querySelector(".methodologytext"),
      //       start: "+=2000px",
      //       end: "+=200px",
      //       scrub: true,
      //       markers: false,
      //     },
      //   }
      // );
    }, []);

    // Cleanup on unmount
    return () => ctx.revert();
  }, []);

  return (
    <div className="overflow-hidden text-white font-sans" ref={ref}>
      <style>
        {`
          @import url('https://fonts.googleapis.com/css2?family=Inter:wght@400;700&family=Roboto+Mono:wght@400;700&display=swap');
          .font-inter {
            font-family: 'Inter', sans-serif;
          }
          .font-roboto-mono {
            font-family: 'Roboto Mono', monospace;
          }
        `}
      </style>
      <div className="w-screen h-[150vh] overflow-hidden relative">
        <div
          className="h-[150vh] w-full bg-cover bg-center absolute top-0 left-0"
          style={{
            backgroundImage:
              "url('https://static.igem.wiki/teams/5096/homepage/home-big-image-2.webp	')",
          }}
        ></div>
        <div className="h-full w-full bg-gradient-to-r from-black via-black/60 to-transparent absolute top-0 left-0"></div>
        <div className="h-full w-full bg-gradient-to-t from-black via-black/10 to-transparent absolute top-0 left-0"></div>

        <div className="absolute h-screen inset-0 flex flex-col justify-start items-start">
          <div className="inset-0 h-screen flex flex-col justify-center items-start px-5">
            <div className="mx-6 md:mx-16 max-w-5xl flex flex-col justify-start">
              <img
                src="https://static.igem.wiki/teams/5096/shieldlogobig.webp"
                alt=""
                className="max-w-xs sm:max-w-sm md:max-w-md lg:max-w-lg xl:max-w-xl"
              />
              <p className="py-2 text-left text-xl sm:text-2xl font-light max-w-xl md:max-w-3xl text-white">
                A new generation of antimicrobials to combat resistance.
              </p>
            </div>
          </div>
        </div>
      </div>

      <section className="flex flex-col items-left pt-8 mx-16 h-screen justify-center problemnumbers">
        <div className="center-left text-pink-500 font-roboto-mono text-md sm:text-lg uppercase mb-4 tracking-widest">
          ANTIMICROBIAL RESISTANCE
        </div>
        <div className="text-3xl sm:text-4xl md:text-6xl mb-8 text-left font-light">
          AMR is one of the most imminent and dangerous threats to global public
          health.
        </div>
        <div className="block md:flex mb-8">
          <div className="bg-[#0A0E7A] text-[#A9C4FF] py-2 px-4 rounded-3xl text-md mr-5 mb-5">
            Directly caused{" "}
            <b className="font-semibold">1.27 million global deaths</b> in 2019
          </div>
          <div className="bg-[#0A0E7A] text-[#A9C4FF] py-2 px-4 rounded-3xl text-md mr-5 mb-5">
            Contributed to <b className="font-semibold">4.95 million deaths</b>{" "}
            in 2019
          </div>
        </div>
      </section>

      <section className="w-full flex justify-center items-center mt-8 globe">
        <Globe year={year} setYear={setYear} />
      </section>

      <section className="pt-2 w-screen  parentsection mt-[50vh]">
        <div className="relative max-w-5xl mx-16 h-screen">
          <div className="absolute statusquotext flex flex-col justify-center top-1/2  transform -translate-y-1/2  opacity-0 ">
            <div className="text-blue-500 text-xl font-roboto-mono  font-bold uppercase tracking-wider mb-4">
              Status Quo
            </div>
            <div className="text-white text-2xl lg:text-4xl leading-relaxed font-light">
              The AMR crisis calls for alternative antibiotics that are able to
              combat the resistance.
            </div>
          </div>

          <div className="absolute methodologytext flex flex-col justify-center top-1/2 transform -translate-y-1/2  opacity-0">
            <div className="text-pink-500 font-roboto-mono text-xl font-bold uppercase tracking-wider mb-4">
              Our Approach
            </div>
            <div className="text-white text-2xl lg:text-4xl leading-relaxed font-light">
              Lambert iGEM created a versatile toolbox for developing novel
              antimicrobials that combat antibiotic-resistant diseases using
              CRISPR-interference, toehold biosensors, and a frugal liquid
              handler.
            </div>
          </div>
        </div>
      </section>

      <section className="w-full h-screen relative flex flex-col pt-20 justify-center items-center mt-16 gifanimation">
        <h1 className="text-2xl lg:text-4xl font-semibold px-5 text-center w-full max-w-xs sm:max-w-sm md:max-w-5xl absolute z-10 top-1/2 left-1/2 transform -translate-x-1/2 -translate-y-1/2">
          We designed a CRISPRi system (dCas9-sgRNA complex) that can
          downregulate a critical gene in a microbe, thereby acting as an
          antimicrobial.
        </h1>
        <img
          src="https://static.igem.wiki/teams/5096/crispri/finalmainanimation-3.gif"
          alt="CRISPRi Mechanism Animation"
          className="my-4 absolute overflow-hidden h-screen"
        />
        <div className="absolute w-full h-full inset-0 bg-black opacity-50"></div>
      </section>

      <section className="w-screen flex flex-col justify-center items-center mt-16">
        <div className=" w-full px-4 py-8">
          <h1 className="text-4xl md:text-6xl py-10 px-16  font-bold">
            A Look Into Our Toolbox
          </h1>
          <div className="">
            <NavLink
              title="PROJECT DESCRIPTION"
              description="Learn more about the detailed decisions that led to our project."
              link="https://2024.igem.wiki/lambert-ga/description/"
            />
            <NavLink
              title="INTEGRATED HUMAN PRACTICES"
              description="Learn more about our conversations with researchers, farmers, and stakeholders that guided our project."
              link="https://2024.igem.wiki/lambert-ga/human-practices/"
            />
            <NavLink
              title="CRISPRI"
              description="Learn about our CRISPRi antimicrobial mechanism and how it works."
              link="https://2024.igem.wiki/lambert-ga/crispri/"
            />
            <NavLink
              title="TOEHOLD"
              description="Learn about how we validated our CRISPRi antimicoribal with toehold biosensors. "
              link="https://2024.igem.wiki/lambert-ga/toeholds/"
            />
            <NavLink
              title="HARDWARE"
              description="Learn about how we simplified lab experimentation for frugal labs."
              link="https://2024.igem.wiki/lambert-ga/hardware/"
            />
            <NavLink
              title="MODEL"
              description="Learn about how we modeled our wetlab reactions and designed toeholds using machine learning."
              link="https://2024.igem.wiki/lambert-ga/model/"
            />
            <NavLink
              title="IMPLEMENTATION"
              description="Learn about how each part of our project comes together in SHIELD's toolbox."
              link="https://2024.igem.wiki/lambert-ga/implementation/"
            />
          </div>
        </div>
      </section>
      <div className="flex w-full justify-center items-center p-5">
        <img
          src="https://static.igem.wiki/teams/5096/a-spexcial-thanq.png"
          alt=""
          className="w-full max-w-2xl rounded-xl"
        />
      </div>

      <Footer />
    </div>
  );
}

function NavLink({
  title,
  description,
  link,
}: {
  title: string;
  description: string;
  link: string;
}) {
  return (
    <a href={link}>
      <div className="group flex justify-between items-center border-t last:border-b border-gray-7 py-10 px-16 hover:bg-gray-1 transition-all duration-300">
        <div className="">
          <h2
            className="group-hover:translate-y-1 transition-all duration-300 font-bold text-3xl md:text-4xl uppercase font-roboto-mono bg-clip-text text-transparent"
            style={{
              backgroundImage: "linear-gradient(to bottom, #ffffff, #999999)",
            }}
          >
            {title}
          </h2>
          <p className="text-gray-300 group-hover:translate-y-[3px] transition-all duration-300">
            {description}
          </p>
        </div>
        <LucideArrowRight
          size="40px"
          className="text-gray-10 group-hover:text-gray-12 transition-all duration-300"
        />
      </div>
    </a>
  );
}

function PlainKey({
  char,
  className,
  textClassName,
}: {
  char: string;
  className?: string;
  textClassName?: string;
}) {
  return (
    <div
      className={
        `min-w-[60px] h-[60px] px-5 py-[21px] flex-grow bg-white rounded-[23px] border border-gray-5 flex-col justify-center items-center gap-2.5 inline-flex m-[9px] ` +
        className
      }
    >
      <div
        className={
          textClassName + ` text-2xl font-medium font-sans leading-[44px] `
        }
      >
        {char}
      </div>
    </div>
  );
}

function LinkKey({ char, link }: { char: string; link: string }) {
  return (
    <a href={link} className="grow flex">
      <PlainKey
        char={char}
        className="group hover:border-yellow-8 shadow-lg hover:bg-yellow-2 transition-all"
        textClassName="text-gray-11 group-hover:text-yellow-11"
      />
    </a>
  );
}

function CommitteeCard({
  title,
  description,
  colorClass,
  href,
}: {
  title: string;
  description: string;
  colorClass: string[];
  href: string;
}) {
  return (
    <div
      className={
        `bg-white rounded-3xl shadow-lg border-[0.5px] p-5 m-2 max-w-[300px] flex flex-col justify-between mb-3 ` +
        colorClass[0]
      }
    >
      <div>
        <h1 className="font-serif text-3xl">{title}</h1>
        <p className="font-sans text-gray-10">{description}</p>
      </div>
      <a
        href={href}
        className={
          `font-regular text-white rounded-xl text-center block p-2 text-lg mt-4 ` +
          colorClass[1]
        }
      >
        Check it out
      </a>
    </div>
  );
}

function PictureCard({ image, caption }: { image: string; caption: string }) {
  return (
    <div className="border-[0.5px] bg-white border-gray-6 rounded-3xl p-8 m-4 shadow-lg max-w-sm max-h-[30rem]">
      <div className="text-black text-xl font-sans">{caption}</div>
      <img
        src={image}
        className="w-full h-96 bg-white rounded-xl mt-8 max-w-sm max-h-sm max-h-72 object-cover"
      />
    </div>
  );
}

export default HomePage;
