import React, { useState } from "react";
import "react-responsive-carousel/lib/styles/carousel.min.css";
import "./carousel-custom.css"; // Ensure this points to your custom CSS
import {
  Carousel,
  CarouselContent,
  CarouselItem,
  CarouselNext,
  CarouselPrevious,
} from "@/components/ui/carousel";
import { type CarouselApi } from "@/components/ui/carousel";

export interface Props {
  images: string[];
  caption?: string;
}

export default function Image(props: Props) {
  // State to track the currently active slide
  const [api, setApi] = React.useState<CarouselApi>();
  const [current, setCurrent] = React.useState(0);
  const [count, setCount] = React.useState(0);

  React.useEffect(() => {
    if (!api) {
      return;
    }

    setCount(api.scrollSnapList().length);
    setCurrent(api.selectedScrollSnap() + 1);

    api.on("select", () => {
      setCurrent(api.selectedScrollSnap() + 1);
    });
  }, [api]);

  return (
    <div className="flex w-full flex-col items-center justify-center p-1">
      <Carousel setApi={setApi}>
        <CarouselContent className="z-0">
          {Array.from({ length: props.images.length }).map((_, index) => (
            <CarouselItem key={index}>
              <img alt={`slide_${index}`} src={props.images[index]} />
            </CarouselItem>
          ))}
        </CarouselContent>
        <CarouselPrevious className="bg-white-1 text-black font-bold w-10 h-10" />
        <CarouselNext className="bg-white-1 text-black font-bold w-10 h-10" />
      </Carousel>
      <div className="py-2 text-center text-sm text-muted-foreground">
        Slide {current} of {count}
      </div>

      <div className="text-center italic">{props.caption}</div>
    </div>
  );
}
