import React, { useEffect, useRef, useLayoutEffect, useState } from "react";
import { gsap } from "gsap";
import { motion, useScroll, useTransform } from "framer-motion";
import { ScrollTrigger } from "gsap/dist/ScrollTrigger";
import {
  AlertTriangleIcon,
  LucideArrowRight,
  LucideArrowRightFromLine,
  MousePointerClick,
} from "lucide-react";
import { useWindowSize } from "@uidotdev/usehooks";

gsap.registerPlugin(ScrollTrigger);

function ProjDescAnim() {
  const ref = useRef<HTMLDivElement>(null);
  const [year, setYear] = useState(2020);
  const windowSize = useWindowSize();

  useEffect(() => {
    const element = ref.current;

    if (!element) return;
    // Use gsap.context for scoping
    let ctx = gsap.context(() => {
      // Create a GSAP timeline with ScrollTrigger
      //problemnumbers
      // Animate the text elements
      const tl = gsap.timeline({
        scrollTrigger: {
          trigger: ".animationsection",
          pin: true,
          scrub: 1,
          start: "top top", // Animation starts when the top of the container hits the top of the viewport
          end: "+2000px",
        },
      });

      tl.to(".horizcontent", { xPercent: -100, duration: 1 });
    });

    // Cleanup on unmount
    return () => ctx.revert();
  }, []);

  return (
    <>
      <section
        className="animationsection overflow-hidden w-full pt-5 pl-5 "
        ref={ref}
      >
        <div className="horizcontent flex w-[5000px] ">
          <img
            src="https://static.igem.wiki/teams/5096/description/projdesc3.svg"
            alt=""
            className="h-screen p-10"
          />
        </div>
      </section>

      {/* <DescriptionMD /> */}
    </>
  );
}

function StoryCard({
  title,
  description,
  imageLink,
}: {
  title: string;
  description: string;
  imageLink: string;
}) {
  return (
    <div className="flex ">
      <div>
        <h1 className="prose prose-h1">{title}</h1>
        <h2 className="prose prose-h2">{description}</h2>
      </div>
      <img src={imageLink} alt="" className="w-96" />
    </div>
  );
}

export default ProjDescAnim;
