"use client";

import React, { useState } from "react";
import { Button } from "@/components/ui/button";
import { Card, CardContent } from "@/components/ui/card";
import {
  Dialog,
  DialogContent,
  DialogHeader,
  DialogTitle,
  DialogDescription,
} from "@/components/ui/dialog";
import { ScrollArea } from "@/components/ui/scroll-area";

export default function Component() {
  return (
    <section className="py-12 lg:py-24 bg-background">
      <div className="container mx-auto px-4">
        <h1 className="text-4xl font-bold text-left mb-12">Members</h1>
        <div className="grid grid-cols-2 md:grid-cols-3 lg:grid-cols-4 gap-6">
          {studentMembers.map((member) => (
            <MemberCard key={member.name} member={member} />
          ))}
        </div>
        <h2 className="text-3xl font-bold text-left py-12">Advisors</h2>
        <div className="grid grid-cols-2 md:grid-cols-3 lg:grid-cols-4 gap-6">
          {advisors.map((member) => (
            <MemberCard key={member.name} member={member} />
          ))}
        </div>
      </div>
    </section>
  );
}

interface Member {
  name: string;
  imgSrc: string;
  description: string;
  role: string;
}

const MemberCard = ({ member }: { member: Member }) => {
  const [isOpen, setIsOpen] = useState(false);

  return (
    <>
      <Card className="overflow-hidden">
        <CardContent className="p-0">
          <Button
            variant="ghost"
            className="w-full h-full p-0 hover:bg-transparent"
            onClick={() => setIsOpen(true)}
          >
            <div className="relative aspect-square">
              <img
                src={member.imgSrc}
                alt={member.name}
                className="object-cover w-full h-full"
              />
              <div className="absolute bottom-0 left-0 right-0 bg-background/80 backdrop-blur-sm p-2 text-left">
                <h3 className="text-lg font-semibold">{member.name}</h3>
                <p className="text-sm text-muted-foreground">{member.role}</p>
              </div>
            </div>
          </Button>
        </CardContent>
      </Card>

      <Dialog open={isOpen} onOpenChange={setIsOpen}>
        <DialogContent className="sm:max-w-[700px] p-0 overflow-hidden">
          <div className="flex">
            <div className="w-1/2 h-[500px]">
              <img
                src={member.imgSrc}
                alt={member.name}
                className="object-cover w-full h-full"
              />
            </div>
            <div className="w-1/2 p-6">
              <DialogHeader>
                <DialogTitle>{member.name}</DialogTitle>
                <DialogDescription>{member.role}</DialogDescription>
              </DialogHeader>
              <ScrollArea className="h-[380px] w-full pr-4 mt-4">
                <p>{member.description}</p>
              </ScrollArea>
            </div>
          </div>
        </DialogContent>
      </Dialog>
    </>
  );
};

const studentMembers = [
  {
    name: "Christina Cho",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/christina1.webp",
    description: `Bonjour! I’m Christina Cho, a senior at Lambert iGEM. This is my third and final year on the team and my third time visiting Paris through iGEM! It’s been an incredible journey of growth in synthetic biology, and iGEM has helped me develop strong wet lab skills and learn far more than I ever imagined possible as a high schooler. Leading this incredible team this year has been an absolute honor, and I can't wait to meet everyone at the Grand Jamboree one last time!`,
    role: "Captain",
  },
  {
    name: "Ryan Du",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/ryan.webp",
    description: `Hi guys! I’m Ryan Du, a senior at Lambert High School and a third time member of the Lambert iGEM team. I’m the tech bro of the team, which means you can usually find me in a corner of the lab coding. When I’m not working hard on software, I’m probably out on an energy drink run to fuel me up before I work on fixing the dozens of pipeline errors in the wiki. I’ve made so many amazing life-long friends and even after I graduate this year iGEM will always have a special place in my heart.  
`,
    role: "Captain",
  },
  {
    name: "Avani Karthik",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/avani1.webp",
    description: `Hi everyone! My name is Avani Karthik, and I am a junior at Lambert. This is my second year on the Lambert iGEM team, and I am so excited to experience the 2024 Giant Jamboree in Paris. iGEM has given me the opportunity to learn so much about both synthetic biology and hardware. In my spare time, you will find me playing tennis, hanging out with my friends, dabbling in photography, or binging TV shows. I can’t wait to meet everyone at Jamboree!`,
    role: "Co-Captain",
  },
  {
    name: "Sean Lee",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/sean.webp",
    description: `Hi everyone, my name is Sean Lee and I’m a junior on Lambert iGEM! This is my first year in the team, and I’m so thankful for the incredible opportunity. iGEM has been crucial not only for my future in biotechnology, but also in my personal development as an individual and a team member. When I’m not locked up in the lab mini prepping, I like to draw, fence, and play video games. Hope to see everyone at Jamboree this year!`,
    role: "Co-Captain",
  },
  {
    name: "Aditya Lagu",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/aditya1.webp",
    description: `Salut! I’m Aditya Lagu, a senior and second year member on the team. Over the last two years, Lambert iGEM has given me opportunities to explore my interests at the intersection of healthcare science and biotech, allowing me to develop my skills in wetlab, hardware, and so much more. When I’m not in the lab, I enjoy playing beach volleyball, eating new foods, and going on hikes. I can’t wait to meet everyone at Jamboree! Au revoir :)
`,
    role: "Member",
  },
  {
    name: "Andrew Jimerson",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/andrew1.webp",
    description: `Hi, My name is Andrew Jimerson and this is my first year on iGEM. I am a Senior at Lambert high school and I am very excited to be at Jamboree this year. IGEM has exposed me to synthetic biology and has sparked a passion for using biology to real-world solve problems. Outside of school, I enjoy playing basketball and tennis. I also love to read and play Monopoly with my friends. I can’t wait to meet everyone at Jamboree.`,
    role: "Member",
  },
  {
    name: "Aria Im",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/aria1.webp",
    description: `Hello everyone! My name is Aria Im, and I am a current junior at Lambert High School. This is my first year participating in iGEM, and I've already learned so much about the fascinating world of biotechnology. Being a part of this competition has opened my eyes to the endless possibilities within the biotech field, and I’m incredibly excited to continue exploring and contributing to this innovative area. I’m particularly thrilled to be here in Paris, meeting other passionate iGEMers from around the world. The opportunity to exchange ideas and collaborate with like-minded individuals is truly inspiring, and I can’t wait to see where this journey takes us all!
`,
    role: "Member",
  },

  {
    name: "Avi Karamchandani",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/avi1.webp",
    description: `Hi everyone! I'm Avi Karamchandani, a senior in high school and a proud member of the Lambert iGEM team. It's my second time stepping into the Grand Jamboree. Further, I've already spent an amazing year immersed in this fascinating field, investing hours a day as a scientist and teammate. Away from the microscope, I take my passion into pickleball, basketball games, and gym sessions. As we prepare for the Jamboree in Paris, I'm eager to share our progress and create new experiences.`,
    role: "Member",
  },
  {
    name: "Claire Lee",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/claire1.webp",
    description: `Hi!! My name is Claire Lee and I’m a junior on the Lambert iGEM team! Throughout this year, I’ve learned so much about synthetic biology and the process of working as a team. When I’m not running reactions or messing with code, I might be listening to music, practicing flute, or hanging out with friends and family. Super excited for Jamboree!`,
    role: "Member",
  },
  {
    name: "Harsha Poonepalle",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/harsha1.webp",
    description: `Hi everyone! My name is Harsha Poonepalle and I am a sophomore in Lambert iGEM, and this is my first year on the team. I have loved working with Lambert iGEM, and it has given me a great opportunity to learn and connect with others. Away from iGEM, you will find me playing squash, hanging out with friends, or playing video games. On se voit à Paris! `,
    role: "Member",
  },
  {
    name: "Jenny Christopher",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/jenny1.webp",
    description: `Hi everyone! My name is Jenny Christopher. I am a senior and this is my first year on Lambert iGEM. Being on the team has given me the opportunity to research interesting topics and develop skills in biotechnology. Outside of iGEM I love to read, paint, and play the violin. I can’t wait to meet everyone at Jamboree!`,
    role: "Member",
  },
  {
    name: "Jeremy Chen",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/jeremy1.webp",
    description: `Hi everyone! My name is Jeremy Chen and I am a junior at Lambert High. This is my first year on the iGEM team and I am thrilled to be in the lab working with everyone on this project. Synthetic biology is so interesting and I have learned so much since joining the team. On the side I enjoy playing board games, watching Studio Ghibli movies, and reading. I can’t wait to meet everybody in Paris this year!`,
    role: "Member",
  },
  {
    name: "Kavya Parimi",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/kavya.webp",
    description: `Hey y’all! I'm Kavya Parimi, currently a senior at Lambert iGEM. This is my second year on the team, and I have had the great honor working on this project with my team members. STEM has always been a big passion of mine and, I am so excited for the opportunity to meet fellow science enthusiasts from around the world at Jamboree. Apart from my passion in STEM I love playing beach volleyball, traveling, and I enjoy hanging out with my friends. I really look forward to meeting everyone at Jamboree this year!`,
    role: "Member",
  },

  {
    name: "Julia Rho",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/julia.webp",
    description: `What’s up! My name’s Julia and I’m a junior in Lambert-iGEM - despite the fact that I stil don’t know how to do stoichiometry… I love all things small and cute (like Benny the Bunny!) and I've perfected the art of last-minute assignment submissions. Inside iGEM, I spend most of my time trying to get enough sleep and not get confused by big words. I’ve made so many interesting? friends here and I can’t wait to make more at Paris! :D`,
    role: "Member",
  },
  {
    name: "Matthew Murad",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/mathew.webp",
    description: `Hey guys! My name is Matthew Murad and I am a senior at Lambert High School. Currently I am the committee lead for the toehold wet-lab committee. Lambert iGEM has been an amazing opportunity to develop my wet-lab and collaboration skills. Aside from iGEM I am part of the Lambert Varsity Track and Field team, I also love to read and spend time with family and friends.`,
    role: "Member",
  },
  {
    name: "Nick Lockhart",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/nick.webp",
    description: `Hey guys! My name is Nick Lockhart and I am in my third and final year on the Lambert High School iGEM team as a senior. I’m typically known as the 3D-printing and hardware guy, but I promise wetlab will always remain number one in my heart. I love to CAD design, build things, and troubleshoot problems. On the side, I play piano and enjoy going to the gym. `,
    role: "Member",
  },
  {
    name: "Reva Badkundri",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/reva.webp",
    description: `Hi everyone! My name is Reva Badkundri, I am a junior and this is my first year on the Lambert iGEM competition team. Lambert iGEM has given me the opportunity to explore my interest in biotechnology, and develop skills in various committees. Outside of iGEM, I love to run, bake, and read. I am so excited to meet everyone at Jamboree!`,
    role: "Member",
  },
  {
    name: "Sankalp Yeleti",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/sankalp.webp",
    description: `Hi everyone, my name is Sankalp Yeleti and I am a junior at Lambert High School. Being on the team has given me the chance to learn so much about synthetic biology, and given me the opportunity to develop my skills and given me experiences to prepare me for the rest of my life! . Outside of iGEM I enjoy swimming competitively, and playing the piano. Can’t wait to meet everyone at Jamboree! 
`,
    role: "Member",
  },

  {
    name: "Sahasra Tatavarti",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/sahasra.webp",
    description: `Hello! My name is Sahasra Tatavarti, and this is my second year on the team. I am a junior, and Lambert iGEM has given me the opportunities and connections to learn and develop skills in Wetlab, Modelling, and Hardware. When I am not in the lab, I love to read any and all books, bake, and listen to music. I am so excited to meet everyone at this year’s Jamboree!`,
    role: "Member",
  },
  {
    name: "Sarvajith Kujuluva",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/sarvajith.webp",
    description: `Hi! My name is Sarvajith Kujuluva, a senior at Lambert High School and a second time member of the Lambert iGEM Team. I am so grateful to have been part of the Lambert iGEM as it has given me amazing opportunities to learn and hone my skills in hardware for the biotechnology field. I have met so many great people on the team and have had countless memories. Outside of iGEM I love sleeping and being surrounded by nature. Can't wait to meet y'all at Jamboree!`,
    role: "Member",
  },
  {
    name: "Srijyoth Ashok",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/srijyoth.webp",
    description: `Bonjour à tous! My name is Srijyoth Ashok, and this is my third year on the team. I am a senior, and I’ve worked in both the hardware and human practices committees. Lambert iGEM has given me amazing opportunities for the past few years, and I’ve gained countless valuable experiences in the field of biotechnology. Outside of iGEM, I love to play sports, go on hikes, and photography!`,
    role: "Member",
  },
  {
    name: "Srishti Iyer",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/srishti.webp",
    description: `Hi everyone! My name is Srishti Iyer and I am a senior on Lambert iGEM, and this is my second year on the team. Lambert iGEM has given me the opportunity to delve deep into the research process, and has allowed me to explore my interests in biotechnology. Outside of iGEM, I love to dance, and take pictures of nature. I am so excited to meet everyone at Jamboree!`,
    role: "Member",
  },

  {
    name: "Shashwat Balamurali",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/shashwat.webp",
    description: `Hi everyone, I’m Shashwat Balamurali, a sophomore at Lambert High School, and I’m excited to be part of the team for the first time this year. Lambert iGEM has given me the perfect platform to dive into my passion for synthetic biology and technology. This year, I’ve had the chance to explore hardware and modeling, while also growing as a team member. Outside of iGEM, I enjoy playing cricket, spending time with family and friends, and exploring different cultures from around the world. I’m eager to continue learning from my team and the broader iGEM community as I embark on this exciting journey!`,
    role: "Member",
  },
  {
    name: "Swadha Surange",
    imgSrc: "https://static.igem.wiki/teams/5096/teampage/swadha.webp",
    description: `Hello everyone! My name is Swadha Surange, and I am a senior and this is my first year on the team. Lambert iGEM has given me opportunities to explore my interests in environmental science and biotech . Outside of iGEM, I enjoy golfing, traveling, and listening to music.`,
    role: "Member",
  },
];

const advisors = [
  {
    name: "Catherine Sharer",
    imgSrc: "https://static.igem.wiki/teams/4683/wiki/teampage/sharer.jpg",
    description: `This is my third year supporting Lambert iGEM and my second year as advisor. I am continually impressed with the curiosity, drive, and creativity of these students. Not only are they bright and hardworking, they are supportive and caring teammates who celebrate each other’s success while also creating a positive learning environment. I have seen that the complex nature of an iGEM project necessitates many hours of brainstorming, project management, and collaboration, and that may be the biggest lesson everyone takes home at the end of the season. After earning my BS in Chemistry/Biochemistry from the Georgia Institute of Technology, I spent a decade as a Sr. Research Specialist and Lab Manager at Emory University and University of Alabama at Birmingham. In 2021 I completed my MAT in Secondary Education Chemistry and started teaching at Lambert High School that fall. As a child, I wanted to run research projects out of the garage like Meg’s parents in A Wrinkle in Time. Getting to collaborate with student scientists every day and take part in their journey may be even better :)`,
    role: "Primary Investigator",
  },
  {
    name: "Dr. Brittney Denier Cantrell",
    imgSrc: "https://static.igem.wiki/teams/4683/wiki/teampage/cantrell.jpg",
    description: `It has been my privilege to support Lambert iGEM since 2012 and advise teams with my amazing counterpart, Janet Standeven, since 2015. In 2022, we welcomed Kate Sharer and Pam Seeley as co-advisors. In these many years, I’ve witnessed hundreds of students learn to think globally and act locally. I predominantly support human practices, educational outreach, and sustainable development, along with the poster, presentation, and wiki. In my role as district secondary science director, I am charged with providing students experiential learning opportunities that allow them to think critically, fail gracefully, and learn from mistakes-what better program than iGEM? To me, the most special part of iGEM is the lifelong friendships I have seen arise within our teams … and the amazing research these young scientists are doing post-secondary. I earned my B.S. in Biology with a concentration in aquatic toxicology from the University of Wyoming, my M.S. in STEM Education with a concentration in plant ecology from the University of North Georgia, and my specialist and doctorate degrees from Valdosta State University in Curriculum and Instruction with a cognate in STEM Education and Minority Studies. I also serve as a Master Instructor for the Georgia Bio Education Institute, a branch of the Office of Workforce Development in the Center for Global Health Innovation. My passion is making science accessible to ALL students. A scientifically literate community benefits us all. When I am not in the lab supporting teachers and students, you can find me backpacking, traveling, painting, and reading.`,
    role: "Advisor",
  },
  {
    name: "Janet Standeven",
    imgSrc: "https://static.igem.wiki/teams/4683/wiki/teampage/standy.jpg",
    description: `I am the Program Director for the NIH SEPA-funded Frugal Science Academy in Georgia Tech’s School of Chemical and Biomolecular Engineering. Prior to my current position I taught Biotechnology and Scientific Research at Lambert High School 2012-2023 and was an iGEM advisor. I have a Bachelor’s degree in Sociology and Anthropology from Millersville University of Pennsylvania and a Master’s Degree from University of Maryland in Chemical Life Science and I am a Master Instructor for GABio Education Institute. One of my driving passions is democratizing access to science through developing frugal science solutions in collaboration with the Bhamla Lab at Georgia Institute of Technology. These collaborations have developed several frugal devices; ElectroPen, 3D-fuge, OpenCell for iGEM teams and we continue to develop ideas to increase accessibility to synthetic biology tools. My work on iGEM’s Human Practices committee helps develop a scientific community aware of the social implications of their work. When I am not in the lab you can find me baking bread, making jam, or traveling.`,
    role: "Advisor",
  },
  {
    name: "Pam Seeley",
    imgSrc: "https://static.igem.wiki/teams/4683/wiki/teampage/seely.jpg",
    description: `I am so excited to be working with Lambert’s iGEM team this year as an advisor. I have been in education for 15 years teaching Biology (on-level, Honors, and AP), Physical Science, and Zoology. Working with the Lambert iGEM team has been an amazing experience. I am constantly amazed by these young researchers commitment to the process of research, resiliency when facing challenges, and collaboration with each other. They truly have a desire to positively impact and improve the world! In my free time… wait, what is that 😉 you can find me at my kids’ activities or curled up with a book.`,
    role: "Advisor",
  },
];
