import * as matter from "gray-matter";
import { remark } from "remark";
import { visit } from "unist-util-visit";
import path from "path";
import fs from "fs";

import { useEffect, useRef, useState } from "react";

export default function TOC({
  headings,
  color,
  className = "",
}: {
  headings: { depth: number; slug: string; text: string }[];
  color: string;
  className?: string;
}) {
  const [currentSection, setCurrentSection] = useState<string>("");

  const handleScroll = () => {
    const sections = headings.map((heading) =>
      document.getElementById(heading.slug)
    );
    const current = sections
      .reverse()
      .find(
        (section) =>
          section &&
          section.getBoundingClientRect().top <= window.innerHeight / 2
      );
    if (current) {
      setCurrentSection(current.id);
    }
  };

  useEffect(() => {
    window.addEventListener("scroll", handleScroll);
    return () => {
      window.removeEventListener("scroll", handleScroll);
    };
  }, [headings]);

  useEffect(() => {
    console.log("current sec", currentSection);
  }, [currentSection]);

  const handleClick = (
    event: React.MouseEvent<HTMLAnchorElement>,
    slug: string
  ) => {
    event.preventDefault();
    const target = document.getElementById(slug);
    if (target) {
      const yOffset = -100;
      const y = target.getBoundingClientRect().top + window.scrollY + yOffset;

      window.scrollTo({ top: y, behavior: "smooth" });
    }
  };

  return (
    <div className={`text-white-1 space-y-3 ${className}`}>
      <h3 className="font-medium">On this page</h3>
      <ul className="space-y-2">
        {headings &&
          headings.map((heading) => (
            <li
              key={heading.slug}
              style={{ marginLeft: `${heading.depth - 1}em` }}
              className={
                currentSection === heading.slug
                  ? `text-${color}-11`
                  : "text-gray-10"
              }
            >
              <a
                href={`#${heading.slug}`}
                onClick={(e) => handleClick(e, heading.slug)}
              >
                {heading.text}
              </a>
            </li>
          ))}
      </ul>
    </div>
  );
}
