import React, { useState } from "react";
import NavButton from "../components/NavButton";
import { motion, useScroll, useMotionValue } from "framer-motion";
import ProgressBar from "../components/ProgressBar";
import Nav from "../components/Nav";
import "@/styles/globals.css";

interface LayoutProps {
  children: React.ReactNode;
  header: string;
  title: string;
}

const styling = `
prose max-w-5xl text-gray-12
prose-h1:font-serif prose-h1:text-4xl
prose-h2:font-sans prose-h2:text-2xl
prose-h3:font-sans prose-h3:text-lg prose-h3:font-semibold prose-h3:text-yellow-800
prose-p:font-sans prose-p:text-gray-900 
prose-a:font-sans prose-a:text-gray-900 prose-a:underline prose-a:font-normal prose-a:text-yellow-800
prose-quoteless
prose-strong
prose-em
prose-ol
prose-ul
prose-li:text-gray-800
prose-table
prose-th
prose-tr
prose-td
prose-img

`;

const Layout = ({ children, header, title }: LayoutProps) => {
  const [openNavBar, setOpenNavBar] = useState(false);

  return (
    <>
      <body className="font-sans w-screen dark">
        {header}
        <div
          className={`bg-cover absolute w-screen left-0 top-0 p-0 m-0 z-10 h-1/2 `}
          style={{
            background: `linear-gradient(to bottom, rgba(255, 255, 255, 0) 36.46%, #FFFFFF 100%), url(${header})`,
            backgroundSize: "cover",
          }}
        />
        <ProgressBar />
        <div className="w-full flex justify-center items-center">
          <div className="flex justify-between m-5 z-50 max-w-6xl grow">
            <a href="https://2024.igem.wiki/lambert-ga/">
              <img
                src="https://static.igem.wiki/teams/5096/shieldlogo.webp"
                alt=""
                width={120}
              />
            </a>
            {/* <NavButton /> */}
            <Nav />
          </div>
        </div>
        <div className="flex justify-center w-full items-center">
          <div className="w-full m-5 max-w-5xl ">
            <p className="font-serif text-5xl sm:text-6xl md:text-7xl font-bold z-30 absolute top-1/2 -translate-y-1/2 ">
              {title}
            </p>
            <div className={styling + "mt-[50vh] break-words grow"}>
              {children}
            </div>
          </div>
        </div>
      </body>
    </>
  );
};

export default Layout;
