import React, { useEffect, useState } from "react";
import NavButton from "../components/NavButton";
import { motion, useScroll, useMotionValue } from "framer-motion";
import ProgressBar from "../components/ProgressBar";
import { icons } from "lucide-react";
import "@/styles/globals.css";

import Nav from "../components/Nav";
import TOC from "../components/toc";
import clsx from "clsx";
interface LayoutProps {
  children: React.ReactNode;
  header: string;
  title: string;
  description: string;
  icon: string;
  color: string;
  headings: any;
  noTOC: boolean;
}

const Layout = ({
  children,
  header,
  title,
  description,
  headings,
  icon,
  color,
  noTOC,
}: LayoutProps) => {
  const [openNavBar, setOpenNavBar] = useState(false);
  const LucideIcon = (icons as any)[icon as any];

  useEffect(() => {
    console.log(headings);
  }, []);
  let descriptionTextColor: string;
  descriptionTextColor =
    color == "blue"
      ? `text-blue-11`
      : color == "magenta"
        ? "text-magenta-11"
        : color == "green"
          ? "text-green-11"
          : "text-pink-11";
  
  let descriptionBGColor: string;
  descriptionBGColor =
    color == "blue"
      ? `bg-blue-9/[0.25]`
      : color == "magenta"
        ? "bg-magenta-8/[0.25]"
        : color == "green"
          ? "bg-green-9/[0.25]"
          : "bg-pink-9/[0.25]";
  
  let accentColor: string;
  accentColor =
    color == "blue"
      ? `accent-blue-9`
      : color == "magenta"
        ? "accent-magenta-9"
        : color == "green"
          ? "accent-green-9"
          : "accent-pink-9";
  
  let proseAAccent: string;
  proseAAccent =
    color == "blue"
      ? `prose-a:text-blue-9`
      : color == "magenta"
        ? "prose-a:text-magenta-9"
        : color == "green"
          ? "prose-a:text-green-9"
          : "prose-a:text-pink-9";
  
  const styling = `

prose
lg:prose-lg
dark:prose-invert
 max-w-4xl text-gray-11 
prose-h1:font-inter prose-h1:text-4xl prose-h1:text-white-1
prose-h2:font-inter prose-h2:text-2xl prose-h2:text-white-1
prose-h3:font-inter prose-h3:text-lg prose-h3:font-semibold prose-h3:text-white-1
prose-p:font-inter prose-p:text-white-1 font-normal leading-relaxed 
prose-a:font-inter prose-a:underline-none prose-a:font-normal 
prose-quoteless
prose-strong
prose-em
prose-ol
prose-ul
prose-li:text-white-1
prose-table:text-white-1
prose-th
prose-tr
prose-td
prose-img:


`;

  return (
    <>
      <body className={clsx("font-sans w-full dark", accentColor)}>
        <div
          className={`bg-cover absolute w-screen left-0 top-0 p-0 m-0 h-2/3 -z-10`}
          style={{
            background: `linear-gradient(to bottom, rgba(255, 255, 255, 0) 36.46%, #0e0e0e 100%), url(${header})`,
            backgroundSize: "cover",
          }}
        />
        {/* <ProgressBar /> */}
        <div className="w-full flex justify-center items-center sticky top-0 pb-2">
          <div className="flex justify-between items-center mt-5 mx-5 max-w-6xl grow">
            <a href="https://2024.igem.wiki/lambert-ga/">
              <img
                src="https://static.igem.wiki/teams/5096/shieldlogo.webp"
                alt=""
                width={120}
              />
            </a>
            {/* <NavButton /> */}
            <Nav />
          </div>
        </div>

        <div className="flex flex-col justify-center w-full items-center h-[50vh] space-y-6">
          <LucideIcon
              size={55}
              className={clsx(
                `flex justify-center w-full items-center`,
                color == "blue"
                ? `text-blue-9`
                : color == "magenta"
                  ? "text-magenta-9"
                  : color == "green"
                    ? "text-green-9"
                    : "text-pink-9"
              )}
            />
          <h1 className="font-inter pb-3 font-bold text-4xl lg:text-8xl md:text-6xl text-center text-white-1">
            {title}
          </h1>
          <p
            className={clsx(
              `rounded-full py-2 px-4 flex justify-center`,
              descriptionTextColor,
              descriptionBGColor
            )}
          >
            {description}
          </p>
        </div>

        <div className="flex justify-center lg:w-full items-start mx-10">
          {!noTOC && (
            <TOC
              headings={headings}
              className="sticky top-0 mx-10 p-0 transition-all duration-400 hidden lg:block"
              color={color}
            />
          )}
          <div className="w-full lg:ml-12 max-w-3xl">
            <div
              className={clsx(
                styling,
                " break-words grow",
                accentColor,
                proseAAccent
              )}
            >
              {children}
            </div>
          </div>
        </div>
      </body>
    </>
  );
};

export default Layout;
