import * as NavigationMenuPrimitive from "@radix-ui/react-navigation-menu";
import clsx from "clsx";
import "@/styles/globals.css";
import { useWindowSize } from "@uidotdev/usehooks";
import React, { useState } from "react";
import { FloatingNav } from "./floating-nav";
import { Sheet, SheetContent, SheetTrigger } from "./ui/sheet";
import { ChevronDown, MenuIcon } from "lucide-react";
import { Button } from "./ui/button";
import { motion, AnimatePresence } from "framer-motion";
export interface NavItemGroup {
  title: string;
  items: NavItemSolo[];
}
function isNavItemGroup(object: any): object is NavItemGroup {
  return "items" in object;
}
export interface NavItemSolo {
  title: string;
  href: string;
}

export default function Nav({ className }: { className?: string }) {
  // const fix = useTriggerFix();
  const windowSize = useWindowSize();
  const schema: (NavItemGroup | NavItemSolo)[] = [
    {
      title: "Team",
      items: [
        { title: "Team", href: "/lambert-ga/team" },
        { title: "Attributions", href: "/lambert-ga/attributions" },
      ],
    },
    {
      title: "Project",
      items: [
        //description, contribution, engineering success, proof of concept
        { title: "Description", href: "/lambert-ga/description" },
        { title: "Contribution", href: "/lambert-ga/contribution" },
        { title: "Engineering Success", href: "/lambert-ga/engineering" },
        { title: "Implementation", href: "/lambert-ga/implementation" },
      ],
    },
    {
      title: "Wetlab",
      items: [
        //parts library, parts collection, CRISPRi, toeholds, experiments, notebook, results
        { title: "Parts Library", href: "/lambert-ga/parts-library" },
        { title: "CRISPRi", href: "/lambert-ga/crisprioverview" },
        { title: "Toeholds", href: "/lambert-ga/toeholds" },
        { title: "Soil Testing", href: "/lambert-ga/soil" },
        { title: "Cell-Free Extraction", href: "/lambert-ga/cell-free" },
        { title: "Experiments", href: "/lambert-ga/experiments" },
        { title: "Notebook", href: "/lambert-ga/notebook" },
        { title: "Results", href: "/lambert-ga/results" },
      ],
    },
    {
      title: "Drylab",
      items: [
        //hardware, software, models
        { title: "Hardware", href: "/lambert-ga/hardware" },
        { title: "Model", href: "/lambert-ga/model" },
      ],
    },
    {
      title: "Integrated Human Practices",
      items: [
        //human practices, soil wetlab, inclusivity, safety
        { title: "Our Approach", href: "/lambert-ga/human-practices" },
        { title: "Education", href: "/lambert-ga/hp-healthcare" },
        { title: "Agriculture", href: "/lambert-ga/hp-agriculture" },
        { title: "Safety", href: "/lambert-ga/safety" },
      ],
    },
  ];
  const MotionLink = motion(NavigationMenuPrimitive.Link);
  const [openGroups, setOpenGroups] = React.useState<string[]>([]);
  const toggleGroup = (title: string) => {
    setOpenGroups((prev) =>
      prev.includes(title) ? prev.filter((t) => t !== title) : [...prev, title]
    );
  };

  return (
    <div className={clsx("flex justify-end z-[60]", className)}>
      {/* <link href="../components/fonts.css" rel="stylesheet" /> */}
      <NavigationMenuPrimitive.Root className="">
        <NavigationMenuPrimitive.List className=" hidden lg:flex flex-row bg-white p-[10px] outline-3 space-x-2 bg-gray-2 rounded-full font-bold text-white-1 shadow-xl z-50">
          {schema.map((item, index) => (
            <div key={index}>
              {isNavItemGroup(item) ? (
                <NavigationMenuPrimitive.Item key={index}>
                  <NavigationMenuPrimitive.Trigger
                    onPointerMove={(event) => event.preventDefault()}
                    onPointerLeave={(event) => event.preventDefault()}
                    className={clsx(
                      "px-5 py-[6px] rounded-full hover:bg-[#5D5D5D]/[.65] transition-colors duration-200",
                      "text-white",
                      "focus:outline-3 focus-visible:ring focus-visible:ring-purple-500 focus-visible:ring-opacity-75 text-[#ffffff]"
                    )}
                    // {...fix}
                  >
                    {item.title}
                  </NavigationMenuPrimitive.Trigger>

                  <NavigationMenuPrimitive.Content
                    style={{ width: "fit-content" }}
                    className={clsx(
                      "absolute rounded-3xl bg-[#3D3D3D]/[.75] mt-2 w-8 backdrop-blur-xl z-50"
                      // "radix-motion-from-start:animate-enter-from-top",
                      // "radix-motion-from-end:animate-enter-from-bottom",
                      // "radix-motion-to-start:animate-exit-to-top",
                      // "radix-motion-to-end:animate-exit-to-bottom"
                    )}
                  >
                    <div className="min-w-48 p-2 flex flex-col z-50">
                      {item.items.map((link, index) => (
                        <NavigationMenuPrimitive.Link
                          href={link.href}
                          key={index}
                          className={`py-2 px-3 border-b ${
                            index != item.items.length &&
                            "z-50 border-gray-6 text-gray-12 font-bold hover:text-[#ff00c2] hover:bg-[#5A5A5A]/[.8] rounded-2xl hover:-translate-y-[1px] transition-all duration-200"
                          }`}
                        >
                          {link.title}
                        </NavigationMenuPrimitive.Link>
                      ))}
                    </div>
                  </NavigationMenuPrimitive.Content>
                </NavigationMenuPrimitive.Item>
              ) : (
                <NavigationMenuPrimitive.Item asChild key={index}>
                  <NavigationMenuPrimitive.Link
                    href={item.href}
                    className={clsx(
                      "px-3 py-[6px] flex h-full w-full justify-center items-center rounded-md hover:bg-white",
                      "font-regular text-gray-11 z-50"
                    )}
                  >
                    {item.title}
                  </NavigationMenuPrimitive.Link>
                </NavigationMenuPrimitive.Item>
              )}
            </div>
          ))}

          <NavigationMenuPrimitive.Indicator
            className={clsx(
              "relative z-50"
              //   "top-[100%] flex items-end justify-center h-2 overflow-hidden",
              // "radix-state-visible:animate-fade-in",
              // "radix-state-hidden:animate-fade-out",
              // "transition-[width_transform] duration-[250ms] ease-[ease]"
            )}
          >
            <NavigationMenuPrimitive.Viewport
              className={clsx(
                "relative shadow-lg rounded-md bg-white z-50",
                "w-radix-navigation-menu-viewport",
                "h-radix-navigation-menu-viewport"
                // "radix-state-open:animate-scale-in-content",
                // "radix-state-closed:animate-scale-out-content",
                // "origin-[top_center] duration-1200 ease-[ease]"
              )}
            />
          </NavigationMenuPrimitive.Indicator>
        </NavigationMenuPrimitive.List>

        <div className="z-50">
          <Sheet>
            <SheetTrigger asChild>
              <Button variant="outline" size="icon" className="lg:hidden">
                <MenuIcon className="h-6 w-6 text-white-1" />
                <span className="sr-only">Toggle navigation menu</span>
              </Button>
            </SheetTrigger>
            <SheetContent side="left">
              <nav className="flex flex-col space-y-4">
                {schema.map((item, index) => (
                  <React.Fragment key={index}>
                    {isNavItemGroup(item) ? (
                      <div>
                        <Button
                          variant="ghost"
                          className="w-full justify-between"
                          onClick={() => toggleGroup(item.title)}
                        >
                          {item.title}
                          <motion.div
                            animate={{
                              rotate: openGroups.includes(item.title) ? 180 : 0,
                            }}
                            transition={{ duration: 0.2 }}
                          >
                            <ChevronDown className="h-4 w-4" />
                          </motion.div>
                        </Button>
                        <AnimatePresence>
                          {openGroups.includes(item.title) && (
                            <motion.div
                              initial={{ opacity: 0, height: 0 }}
                              animate={{ opacity: 1, height: "auto" }}
                              exit={{ opacity: 0, height: 0 }}
                              transition={{ duration: 0.3, ease: "easeInOut" }}
                            >
                              <div className="space-y-2 ml-4 mt-2">
                                {item.items.map((subItem, subIndex) => (
                                  <MotionLink
                                    key={subIndex}
                                    href={subItem.href}
                                    className="block py-2 px-4 text-sm hover:bg-accent hover:text-accent-foreground rounded-md"
                                    initial={{ opacity: 0, x: -10 }}
                                    animate={{ opacity: 1, x: 0 }}
                                    exit={{ opacity: 0, x: -10 }}
                                    transition={{
                                      duration: 0.2,
                                      delay: subIndex * 0.05,
                                    }}
                                  >
                                    {subItem.title}
                                  </MotionLink>
                                ))}
                              </div>
                            </motion.div>
                          )}
                        </AnimatePresence>
                      </div>
                    ) : (
                      <NavigationMenuPrimitive.Link
                        href={item.href}
                        className="block py-2 px-4 text-sm hover:bg-accent hover:text-accent-foreground rounded-md"
                      >
                        {item.title}
                      </NavigationMenuPrimitive.Link>
                    )}
                  </React.Fragment>
                ))}
              </nav>
            </SheetContent>
          </Sheet>
        </div>
      </NavigationMenuPrimitive.Root>
    </div>
  );
}
